@@ -30,11 +30,11 @@ namespace Baloo {
 class BALOO_ENGINE_EXPORT PhraseAndIterator : public PostingIterator
 {
 public:
-    PhraseAndIterator(const QVector<PostingIterator*>& iterators);
+    explicit PhraseAndIterator(const QVector<PostingIterator*>& iterators);
     ~PhraseAndIterator();
 
-    quint64 next();
-    quint64 docId() const;
+    quint64 next() override;
+    quint64 docId() const override;
 
 private:
     QVector<PostingIterator*> m_iterators;
